@@ -20,19 +20,23 @@ class InitializeTcellContextTest(unittest.TestCase):
         request.path = MagicMock(return_value="/some/path")
         request.get_full_path = MagicMock(return_value="/some/path?param=hi")
         request.build_absolute_uri = MagicMock(return_value="http://localhost/some/path?param=hi")
-        with patch("tcell_agent.instrumentation.djangoinst.meta.better_ip_address",
-                   return_value="1.1.1.1") as patched_better_ip_address:
-            initialize_tcell_context(request)
-            tcell_context = request._tcell_context
-            self.assertTrue(patched_better_ip_address.called)
-            self.assertIsNotNone(tcell_context.referrer, "referrer")
-            self.assertIsNotNone(tcell_context.user_agent, "user-agent")
-            self.assertIsNotNone(tcell_context.remote_address, "1.1.1.1")
-            self.assertIsNotNone(tcell_context.method, "GET")
-            self.assertIsNotNone(tcell_context.path, "/some/path")
-            self.assertIsNotNone(tcell_context.fullpath, "/some/path?param=hi")
-            self.assertIsNotNone(tcell_context.uri, "http://localhost/some/path?param=hi")
-            self.assertIsNone(tcell_context.route_id)
+        with patch("tcell_agent.instrumentation.djangoinst.meta.get_remote_address",
+                   return_value="1.1.1.1") as patched_get_remote_address:
+            with patch("tcell_agent.instrumentation.djangoinst.meta.get_reverse_proxy_header",
+                       return_value="2.2.2.2") as patched_get_reverse_proxy_header:
+                initialize_tcell_context(request)
+                tcell_context = request._tcell_context
+                self.assertTrue(patched_get_remote_address.called)
+                self.assertTrue(patched_get_reverse_proxy_header.called)
+                self.assertIsNotNone(tcell_context.referrer, "referrer")
+                self.assertIsNotNone(tcell_context.user_agent, "user-agent")
+                self.assertIsNotNone(tcell_context.remote_address, "1.1.1.1")
+                self.assertIsNotNone(tcell_context.reverse_proxy_header_value, "2.2.2.2")
+                self.assertIsNotNone(tcell_context.method, "GET")
+                self.assertIsNotNone(tcell_context.path, "/some/path")
+                self.assertIsNotNone(tcell_context.fullpath, "/some/path?param=hi")
+                self.assertIsNotNone(tcell_context.uri, "http://localhost/some/path?param=hi")
+                self.assertIsNone(tcell_context.route_id)
 
 
 class GetAppsensorMetaTest(unittest.TestCase):
