@@ -3,7 +3,7 @@ from __future__ import print_function
 import unittest
 
 import pytest
-from mock import call, patch
+from mock import patch
 
 
 from tcell_agent.agent import TCellAgent
@@ -32,16 +32,6 @@ class CheckAgentStartupTest(unittest.TestCase):
     def test_agent_sends_startup_info_start_agent(self):
         with patch.object(TCellAgent, "startup", return_value=True) as patched_startup:
             with patch("tcell_agent.instrumentation.flaskinst.routes.report_routes", return_value=None) as patched_report_routes:
-                with patch.object(TCellAgent, "send", return_value=None) as patched_send:
-                    start_agent()
-                    self.assertTrue(patched_report_routes.called)
-                    self.assertTrue(patched_startup.called)
-                    patched_send.assert_has_calls(
-                        [
-                            call({
-                                "event_type": "server_agent_details",
-                                "app_framework": "Flask",
-                                "app_framework_version": __version__
-                            })
-                        ]
-                    )
+                start_agent()
+                self.assertTrue(patched_report_routes.called)
+                self.assertTrue(patched_startup.called)
